%define ALD_Ver		1.2.1

Name:         syslinux

License:      GPL
Summary:      Kernel loader which uses a FAT, ext2/3 or iso9660 filesystem or a PXE network
Group:        System/Boot
Version:      4.06
Release:      1

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/System
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 0
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_prefix	%{csysdir}%{_prefix}
%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}
# ------------------- description ------------------------------------
%description
SYSLINUX is a suite of bootloaders, currently supporting DOS FAT
filesystems, Linux ext2/ext3 filesystems (EXTLINUX), PXE network boots
(PXELINUX), or ISO 9660 CD-ROMs (ISOLINUX).  It also includes a tool,
MEMDISK, which loads legacy operating systems from these media.
#-------------------------------
%package all-drv
Summary:      all syslinux Kernel loader
Group:        System/Boot
%description all-drv
all syslinux Kernel loader DOS FAT, PXE network, ..
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}

# ------------------- setup ------------------------------------------
%prep
%setup -q
#patch0 -b .orig -p0

# ------------------- Build ------------------------------------------
%build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -std=gnu99"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS -Wl,--gc-sections"

CXXFLAGS="OPTFLAGS"
CC="%{target_}gcc"
export CFLAGS CC

make clean &>/dev/null
make CC=%{target_}gcc OPTFLAGS="$CFLAGS" installer &>FMake_log.txt
#make  -C sample tidy

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{docdir}

make CC=%{target_}gcc local-install \
	INSTALLROOT=%{buildroot} BINDIR=%{_bindir} SBINDIR=%{_sbindir} \
	LIBDIR=%{_libdir} DATADIR=%{_datadir} \
	MANDIR=%{_mandir} INCDIR=%{_includedir} \
	TFTPBOOT=/tftpboot EXTLINUXDIR=/boot/extlinux \
	&>FInstall_log.txt
#make CC='%{my_cc}' -C sample tidy
#mkdir -p $RPM_BUILD_ROOT/etc
#( cd $RPM_BUILD_ROOT/etc && ln -s ../boot/extlinux/extlinux.conf . )

cp -ar COPYING NEWS README doc $RPM_BUILD_ROOT%{docdir}/
cp -ar sample $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-all-drv-$SE $DD/%{name}-all-drv-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%files
%defattr(-,root,root)
#%{_sysconfdir}
%{_sbindir}
%{_mandir}/man*/*
%{_bindir}
%{_datadir}/syslinux/chain.c32
%{_datadir}/syslinux/isolinux.bin
%{_datadir}/syslinux/mbr.bin
%{_datadir}/syslinux/memdisk
%{_datadir}/syslinux/menu.c32
%{_datadir}/syslinux/vesainfo.c32
%{_datadir}/syslinux/vesamenu.c32
%{docdir}/COPYING
%{docdir}/README

%files all-drv
%{_datadir}/syslinux
%exclude %{_datadir}/syslinux/chain.c32
%exclude %{_datadir}/syslinux/isolinux.bin
%exclude %{_datadir}/syslinux/mbr.bin
%exclude %{_datadir}/syslinux/memdisk
%exclude %{_datadir}/syslinux/menu.c32
%exclude %{_datadir}/syslinux/vesainfo.c32
%exclude %{_datadir}/syslinux/vesamenu.c32

%files doc
%{docdir}/doc
%{docdir}/sample
%{docdir}/NEWS
